@@ -162,6 +162,11 @@ async def make_request_obj_from_request(request: FastAPIRequest):
         context = request.scope['aws.context']
         [setattr(request_obj, field, getattr(context, field)) for field in aws_fields]
 
+        cloudwatch_base_url = 'https://console.aws.amazon.com/cloudwatch/home?region=us-east-1#logStream:group='
+        request_obj.log_group_url = f'{cloudwatch_base_url}{request_obj.log_group_name}'
+        request_obj.stream_url = f'{request_obj.log_group_url};stream={request_obj.log_stream_name}'.replace(
+            '[$LATEST]', '%5B$LATEST%5D')
+
     if 'aws.event' in request.scope:
         event = request.scope['aws.event']
         request_context = event.get('requestContext')
@@ -170,10 +175,6 @@ async def make_request_obj_from_request(request: FastAPIRequest):
             request_obj.domain_name = request_context.get('domainName')
             request_obj.api_id = request_context.get('apiId')
 
-    cloudwatch_base_url = 'https://console.aws.amazon.com/cloudwatch/home?region=us-east-1#logStream:group='
-    request_obj.log_group_url = f'{cloudwatch_base_url}{request_obj.log_group_name}'
-    request_obj.stream_url = f'{request_obj};stream={request_obj.log_stream_name}'.replace('[$LATEST]', '%5B$LATEST%5D')
-
     return request_obj
 
 
