@@ -117,7 +117,7 @@ def create_handler(app):
         # print('contect_dict', context.__dict__)
         # print('sls sdk', context.serverless_sdk)
 
-        # print("EVENTD", event)
+        print("EVENTD", event)
 
         asgi_handler = Mangum(app, api_gateway_base_path=g.settings.stage)
         response = asgi_handler(event, context)
